# NNSVS

[![][docs-latest-img]][docs-latest-url]
[![PyPI](https://img.shields.io/pypi/v/nnsvs.svg)](https://pypi.python.org/pypi/nnsvs)
[![License](http://img.shields.io/badge/license-MIT-brightgreen.svg?style=flat)](LICENSE)
![Python CI](https://github.com/nnsvs/nnsvs/workflows/Python%20CI/badge.svg)
[![codecov](https://codecov.io/gh/nnsvs/nnsvs/branch/master/graph/badge.svg?token=Z66FDOQGH7)](https://codecov.io/gh/nnsvs/nnsvs)

[docs-latest-img]: https://img.shields.io/badge/docs-latest-blue.svg
[docs-latest-url]: https://nnsvs.github.io/nnsvs/

Neural network-based singing voice synthesis library for research

Documentation can be found at https://nnsvs.github.io.
